%--------------------------------------------------------------------------
% TESTING QUALITY APPROXIMATE FEKETE (LEJA) POINTS FOR INTERPOLATION AND
% CUBATURE.
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%% Copyright (C) 2010
%% Len Bos, Stefano De Marchi, Alvise Sommariva, Marco Vianello.
%%
%% This program is free software; you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation; either version 2 of the License, or
%% (at your option) any later version.
%%
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%%
%% Author:
%%          Len Bos           <leonardpeter.bos@univr.it>
%%          Stefano De Marchi <demarchi@math.unipd.it>
%%          Alvise Sommariva  <alvise@math.unipd.it>
%%          Marco Vianello    <marcov@math.unipd.it>
%%
%% Date: May 24, 2010.
%--------------------------------------------------------------------------

clear all;

degv=6:18;           % deg: WAM DEGREE.
extraction_method=1; % extraction_method: 1: QR 2:LU.

family_type=2;

starting_point=0;

mildness_vector=4;
verbosity=2; % * UNCONSTRAINED: 
             % 0-1: MEDIUM SCALE (ITER OFF/ON) 2-3: LARGE SCALE (OFF/ON).
             % * CONSTRAINED: 
             % 0-1: ITER ON/OFF.
costrained_optimization=0; % 0: UNCONSTRAINED. 1: CONSTRAINED OPTIMIZATION.


do_plots=0;

%--------------------------------------------------------------------------
%               ...... HERE THE MAIN PROGRAM BEGINS ......
%--------------------------------------------------------------------------

s='set_disk_leb'; % PUT THE NAME OF YOUR FUNCTION HERE (WITHOUT .m EXTENSION).
diaryname=cat(2,'diary_',date,'_',s,'.m');

diary on; diary(diaryname);

fprintf('\n \t ');
uu=cat(2,'function pts=',s,'(deg)');
fprintf(uu);


for kk=1:length(degv)

    deg=degv(kk);



    %--------------
    % INITIAL SET.
    %--------------

    switch starting_point
        case 0
            pts_start=set_disk_leb(deg);
        case 1
            pts_wam=disk_wam(deg);
            V_wam= koornwinder_typeII(deg,pts_wam,-0.5);
            [pts_start,w_disk,ind,C,P]=computing_fekete_points(...
                pts_wam,V_wam,2,[],extraction_method);
    end

    %---------------
    % OPTIMIZATION.
    %---------------

    pts_in=pts_start;
    cputiming1=cputime;
    for ii=1:length(mildness_vector)
        mildness=mildness_vector(ii);
        if costrained_optimization == 1
            [pts_out,value]=general_constrained_optimization_disk(deg,...
                pts_in,family_type,mildness,verbosity);
        else
            [pts_out,value]=general_unconstrained_optimization_disk(deg,...
                pts_in,family_type,mildness,verbosity);
        end
        pts_in=pts_out;
    end
    cputiming2=cputime;

    %-------
    % STATS.
    %-------
    timing=cputiming2-cputiming1;
    [lebs,dets,conds]=do_stats(deg,pts_out,timing);


    %-------
    % PLOTS.
    %-------
    if do_plots == 1
        degrees=linspace(0,2*pi,1000); degrees=degrees';
        pts_bnd=[cos(degrees) sin(degrees)];
        plot(pts_bnd(:,1),pts_bnd(:,2),'b-',...
            pts_out(:,1),pts_out(:,2),'r+');
    end

end
