
%--------------------------------------------------------------------------
%% Copyright (C) 2010
%% Len Bos, Stefano De Marchi, Alvise Sommariva, Marco Vianello.
%%
%% This program is free software; you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation; either version 2 of the License, or
%% (at your option) any later version.
%%
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%%
%% Author:
%%          Matteo Briani
%%          Alvise Sommariva  <alvise@math.unipd.it>
%%          Marco Vianello    <marcov@math.unipd.it>
%%
%% Date: Dicember 20, 2010.
%--------------------------------------------------------------------------

clear all;

degv=15;             % deg: POLYNOMIAL DEGREE. IT CAN BE A VECTOR.
extraction_method=1; % extraction_method: 1: QR (AFP) 2:LU (DLP).

family_type=2; % 1: FEKETE 2: LEBESGUE.

starting_point=2; % 0: BEST SET. 1: AFP.

mildness_vector=8:9;

%--------------------------------------------------------------------------
%               ...... HERE THE MAIN PROGRAM BEGINS ......
%--------------------------------------------------------------------------

s='set_simplex_fek'; % PUT THE NAME OF YOUR FUNCTION HERE (WITHOUT .m EXTENSION).
diaryname=cat(2,'diary_',date,'_',s,'.m');

diary on; diary(diaryname);

fprintf('\n \t ');
uu=cat(2,'function pts=',s,'(deg)');
fprintf(uu);

fprintf('\n \t switch deg');

for kk=1:length(degv)

    deg=degv(kk);

    %--------------
    % INITIAL SET.
    %--------------

    switch starting_point
        case 0
            if family_type == 1
                pts_start=set_simplex_fek(deg);
            else
                pts_start=set_simplex_leb(deg);
            end
        case 1
            wam_deg=30;
            pts_wam=simplex_wam(wam_deg);
            V_wam= dubiner_leg(deg,pts_wam);
            [pts_start,w_simplex,ind,C,P]=computing_fekete_points(...
                pts_wam,V_wam,2,[],extraction_method);
        case 2
            pts_start=set_simplex_leb_gll(deg);
            pts_start=set_simplex_fek(deg);
    end

    %---------------
    % OPTIMIZATION.
    %---------------

    pts_in=pts_start;

    [lebs,dets,conds]=do_stats(deg,pts_in,[],0);
    cputiming1=cputime;

    if family_type == 1
        value_new=abs(dets); value_old=abs(dets)/2; value_init=value_new;
    else
        value_new=abs(lebs); value_old=2*abs(lebs); value_init=value_new;
    end


    for jj=1:100

        if abs(value_new - value_old) > 10^(-3)*abs(value_old)

            value_old=value_new;
            [pts_out,value_new]=iterative_step(deg,pts_in,...
                family_type,value_new,mildness_vector);
            pts_in=pts_out;

        end

    end

    if family_type == 1
        if abs(value_new) > abs(value_init)
            fprintf('\n \t %% [+]: OLD: %2.5e NEW: %2.5e',value_init,...
                value_new);
        else
            fprintf('\n \t %% [=]: OLD: %2.5e NEW: %2.5e',value_init,...
                value_new);
        end
    else
        if value_new < value_init
            fprintf('\n \t %% [+]: OLD: %2.5e NEW: %2.5e',value_init,...
                value_new);
        else
            fprintf('\n \t %% [=]: OLD: %2.5e NEW: %2.5e',value_init,...
                value_new);
        end
    end


    cputiming2=cputime;

    %-------
    % STATS.
    %-------
    timing=cputiming2-cputiming1;
    [lebs,dets,conds]=do_stats(deg,pts_out,timing,1);

end
