
function [lebs,dets,conds,errs]=do_stats(deg,pts,timing,print_stats)

if nargin < 3
    timing=0;
end

if nargin < 4
    print_stats=1;
end

errs=0;

%-------------------------------------------------
% CHECKING IF THE POINTS ARE IN THE UNIT DISK.
% SOME MINIMAL CORRECTIONS.
%-------------------------------------------------

if print_stats == 1
    fprintf('\n \n \t case %2.0f ',deg);
end
x=pts(:,1); y=pts(:,2);


s = (x >= 0) +  (y >= 0) + (x <= 1) +  (y <= 1) + (x + y <= 1) -5;

if norm(s) == 0
    if print_stats == 1
        fprintf('\n \n \t %% PASSED (I).');
    end
else
    % fprintf('\n \n \t %% CHECKING MORE, SOME FAILURE.');

    ix=find(x < 0);
    pts(ix,1)=0.000000000000000000000000000000e+00;

    ix=find(x > 1);
    pts(ix,1)=1.000000000000000000000000000000e+00;

    iy=find(y < 0);
    pts(iy,2)=0.000000000000000000000000000000e+00;

    iy=find(y > 1);
    pts(iy,2)=1.000000000000000000000000000000e+00;

    xp=pts(:,1); yp=pts(:,2);

    ss=find(xp + yp > 1);
    for index=1:length(ss)
        ssloc=ss(index); xx=xp(ssloc); yy=yp(ssloc);
        if xx > yy
            pts(ssloc,2)=1-xx;
        else
            pts(ssloc,1)=1-yy;
        end
    end
    xp=pts(:,1); yp=pts(:,2);

    sp = (xp >= 0) +  (yp >= 0) + (xp <= 1) +  (yp <= 1) + (xp + yp <= 1) -5;
    if norm(sp) == 0
        if print_stats == 1
            fprintf('\n \n \t %% PASSED (II).');
        end
    else
        if print_stats == 1
            fprintf('\n \n \t %% CHECK AFTER POSTPRODUCTION');
        end
        errs=1;
        % [(1:length(x))' (xp >= 0)  (yp >= 0) (xp <= 1)  (yp <= 1) (xp + yp <= 1)]
    end
end

%---------------------------
% COMPUTING BASIC CONSTANTS.
%---------------------------

V_pts=dubiner_leg(deg,pts);
dets=det(V_pts);

pts_leb=simplex_wam(250);
V_leb= dubiner_leg(deg,pts_leb);

lebs=norm(V_pts'\V_leb',1);
conds=condest(V_pts);

%-----------------------
% DISPLAYING CONSTANTS.
%-----------------------
if print_stats == 1
    fprintf('\n \n \t %% DEGREE: %3.0f',deg);
    fprintf('\n \t %% POINTS: %6.0f',size(pts,1));
    fprintf('\n \t %% LEBESGUE CONSTANT: %2.5e',lebs);
    fprintf('\n \t %% DETERMINANT: %2.5e',dets);
    fprintf('\n \t %% CONDITIONING: %2.5e',conds);
    fprintf('\n \t %% VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.');
    if timing > 0
        minuti=floor(timing/60);
        secondi=floor(timing-minuti*60);
        fprintf('\n \t %% CPUTIME (MINUTES:SECONDS): %4.0f : %2.0f.\n',minuti,...
            secondi);
    else
        fprintf('\n');
    end
end

%-----------------------
% DISPLAYING POINTS.
%-----------------------
if print_stats == 1
    fprintf('\n \t pts=[');
    for kk=1:size(pts,1)
        fprintf('\n \t %1.30e %1.30e',pts(kk,1),pts(kk,2));
    end
    fprintf('\n \t ]; \n ');
end
